Shared Preferences are XML files to store private primitive data in key-value pairs. Data Types include Booleans, floats, ints, longs, and strings.

Shared preferences must be set with the permission MODE\_WORLD\_READABLE, unless explicity required for sharing information across apps.